Python Color Math Module (colormath)
====================================

.. image:: https://travis-ci.org/gtaylor/python-colormath.png?branch=master
        :target: https://travis-ci.org/gtaylor/python-colormath
.. image:: https://pypip.in/d/colormath/badge.png
        :target: https://crate.io/packages/colormath/

This module implements a large number of different color operations such as
color space conversions, Delta E, and density to spectral.

Requirements
------------

* numpy
* NetworkX 2.0+
* Python 2.7 or Python 3.5+

Installation
------------

The easiest way to install colormath is via pip/easy_install::

    pip install colormath

Documentation
-------------

For documentation, see the project webpage at:

    http://python-colormath.readthedocs.org/
    
There are also a lot of useful examples under the examples directory within
this directory.

Support
-------

Head over to https://github.com/gtaylor/python-colormath
and submit an issue if you have any problems or questions.

Legal Mumbo Jumbo
-----------------

Copyright (C) 2018 `Gregory Taylor`_

This software is licensed under the BSD License.

.. _Gregory Taylor: http://gc-taylor.com
